@@ -2,9 +2,9 @@ import torch
 
 
 class PlusResidual(torch.nn.Module):
-    def __init__(self, residual):
+    def __init__(self, layer):
         super().__init__()
-        self.residual = residual
+        self.layer = layer
 
     def forward(self, x):
-        return x + self.residual(x)
+        return x + self.layer(x)
